@@ -10,16 +10,20 @@ SOLIDserver network manager
 
 """
 
+# pylint: disable=too-many-branches
+
 import math
 
+from packaging.version import Version, parse
+from SOLIDserverRest.Exception import (SDSEmptyError, SDSError,
+                                       SDSNetworkError,
+                                       SDSNetworkNotFoundError)
+
+from .class_params import ClassParams
+
 # loggingimport logging
 # import pprint
 
-from SOLIDserverRest.Exception import SDSError, SDSEmptyError
-from SOLIDserverRest.Exception import SDSNetworkError, SDSNetworkNotFoundError
-
-from .class_params import ClassParams
-
 
 # pylint: disable=R0902
 class Network(ClassParams):
@@ -74,6 +78,7 @@ class Network(ClassParams):
 
         self.params = {
             'subnet_id': None,
+            'parent_subnet_id': None
         }
 
     # -------------------------------------
@@ -213,7 +218,12 @@ class Network(ClassParams):
             if page > limit:
                 params['limit'] = limit
 
-        params['WHERE'] = "site_id='{}'".format(self.space.params['site_id'])
+        if 'WHERE' not in params:
+            params['WHERE'] = ""
+        else:
+            params['WHERE'] += " and "
+
+        params['WHERE'] += "site_id='{}'".format(self.space.params['site_id'])
 
         if depth == 1:
             params['WHERE'] += "and parent_subnet_id='{}'".format(self.myid)
@@ -301,8 +311,6 @@ class Network(ClassParams):
 
         self.prepare_class_params('network', params)
 
-        # logging.info(params)
-
         rjson = self.sds.query("ip_subnet_create",
                                params=params)
 
@@ -381,7 +389,6 @@ class Network(ClassParams):
             **self.additional_params
         }
 
-        # logging.info(params)
         try:
             rjson = self.sds.query("ip_subnet_info",
                                    params=params)
@@ -393,24 +400,26 @@ class Network(ClassParams):
         rjson = rjson[0]
         # logging.info(rjson)
 
-        for label in ['subnet_id',
-                      'subnet_name',
-                      'start_hostaddr',
-                      'end_hostaddr',
-                      'subnet_size',
-                      'subnet_level',
-                      'parent_subnet_id',
-                      'is_terminal',
-                      'subnet_allocated_size',
-                      'subnet_allocated_percent',
-                      'subnet_used_size',
-                      'subnet_used_percent',
-                      'subnet_ip_used_size',
-                      'subnet_ip_used_percent',
-                      'subnet_ip_free_size',
-                      'is_in_orphan',
-                      'lock_network_broadcast',
-                      'tree_level']:
+        labels = ['subnet_id',
+                  'subnet_name',
+                  'subnet_size',
+                  'subnet_level',
+                  'parent_subnet_id',
+                  'is_terminal',
+                  'subnet_allocated_size',
+                  'subnet_allocated_percent',
+                  'subnet_used_size',
+                  'subnet_used_percent',
+                  'subnet_ip_used_size',
+                  'subnet_ip_used_percent',
+                  'subnet_ip_free_size',
+                  'is_in_orphan',
+                  'lock_network_broadcast',
+                  'tree_level']
+        if parse(self.sds.get_version()) >= Version("7.0.0"):
+            labels.extend(['start_hostaddr', 'end_hostaddr'])
+
+        for label in labels:
             if label not in rjson:  # pragma: no cover
                 msg = "parameter {} not found in network".format(label)
                 raise SDSNetworkError(msg)
@@ -426,6 +435,9 @@ class Network(ClassParams):
             else:
                 self.is_block = False
 
+        if 'start_hostaddr' in rjson:
+            self.subnet_addr = rjson['start_hostaddr']
+
         # should be this variable (see API doc), but not working...
         if 'network_class_parameters' in rjson:   # pragma: no cover
             self.update_class_params(rjson['network_class_parameters'])
@@ -457,6 +469,9 @@ class Network(ClassParams):
         return_val += self.str_params(exclude=['subnet_id',
                                                'subnet_name'])
 
+        if self.parent_network:
+            return_val += " parent={}".format(self.parent_network.myid)
+
         return_val += str(super().__str__())
 
         return return_val
